Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/npm/cli.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorisaacs <i@izs.me>2013-02-06 19:02:06 +0400
committerisaacs <i@izs.me>2013-02-06 19:02:06 +0400
commitd714dbdbda57e30e52cec153013f704646b0f764 (patch)
treebb628e2fcf83a6b54450c86b18cc297af3468448 /node_modules/rimraf
parente6e6a3e873ff3335367a9e4f193b8719cf7bcfcb (diff)
rimraf@2.1.4
Diffstat (limited to 'node_modules/rimraf')
-rw-r--r--node_modules/rimraf/package.json4
-rw-r--r--node_modules/rimraf/rimraf.js4
2 files changed, 4 insertions, 4 deletions
diff --git a/node_modules/rimraf/package.json b/node_modules/rimraf/package.json
index d60c92ede..679ee6b03 100644
--- a/node_modules/rimraf/package.json
+++ b/node_modules/rimraf/package.json
@@ -1,6 +1,6 @@
{
"name": "rimraf",
- "version": "2.1.3",
+ "version": "2.1.4",
"main": "rimraf.js",
"description": "A deep deletion module for node (like `rm -rf`)",
"author": {
@@ -47,7 +47,7 @@
],
"readme": "A `rm -rf` for node.\n\nInstall with `npm install rimraf`, or just drop rimraf.js somewhere.\n\n## API\n\n`rimraf(f, callback)`\n\nThe callback will be called with an error if there is one. Certain\nerrors are handled for you:\n\n* `EBUSY` - rimraf will back off a maximum of opts.maxBusyTries times\n before giving up.\n* `EMFILE` - If too many file descriptors get opened, rimraf will\n patiently wait until more become available.\n\n\n## rimraf.sync\n\nIt can remove stuff synchronously, too. But that's not so good. Use\nthe async API. It's better.\n",
"readmeFilename": "README.md",
- "_id": "rimraf@2.1.3",
+ "_id": "rimraf@2.1.4",
"dependencies": {
"graceful-fs": "~1"
},
diff --git a/node_modules/rimraf/rimraf.js b/node_modules/rimraf/rimraf.js
index 6c8bf98ec..ed915f982 100644
--- a/node_modules/rimraf/rimraf.js
+++ b/node_modules/rimraf/rimraf.js
@@ -69,11 +69,11 @@ function rimraf_ (p, cb) {
}
function rmdir (p, originalEr, cb) {
// try to rmdir first, and only readdir on ENOTEMPTY
// if we guessed wrong, and it's not a directory, then
// raise the original error.
fs.rmdir(p, function (er) {
- if (er && er.code === "ENOTEMPTY")
+ if (er && (er.code === "ENOTEMPTY" || er.code === "EEXIST"))
rmkids(p, cb)
else if (er && er.code === "ENOTDIR")
cb(originalEr)
@@ -69,11 +69,11 @@ function rimraf_ (p, cb) {
}
function rmdir (p, originalEr, cb) {
- // try to rmdir first, and only readdir on ENOTEMPTY
+ // try to rmdir first, and only readdir on ENOTEMPTY or EEXIST (SunOS)
// if we guessed wrong, and it's not a directory, then
// raise the original error.